@@ -1,7 +1,7 @@
 package Sort::Sub::ascii_then_num;
 
-our $DATE = '2016-12-16'; # DATE
-our $VERSION = '0.07'; # VERSION
+our $DATE = '2016-12-17'; # DATE
+our $VERSION = '0.08'; # VERSION
 
 use 5.010;
 use strict;
@@ -57,10 +57,40 @@ Sort::Sub::ascii_then_num - Sort non-numbers (sorted asciibetically) before numb
 
 =head1 VERSION
 
-This document describes version 0.07 of Sort::Sub::ascii_then_num (from Perl distribution Sort-Sub), released on 2016-12-16.
+This document describes version 0.08 of Sort::Sub::ascii_then_num (from Perl distribution Sort-Sub), released on 2016-12-17.
 
 =for Pod::Coverage ^(gen_sorter)$
 
+=head1 SYNOPSIS
+
+Generate sorter (accessed as variable) via L<Sort::Sub> import:
+
+ use Sort::Sub '$ascii_then_num'; # use '$ascii_then_num<i>' for case-insensitive sorting, '$ascii_then_num<r>' for reverse sorting
+ my @sorted = sort $ascii_then_num ('item', ...);
+
+Generate sorter (accessed as subroutine):
+
+ use Sort::Sub 'ascii_then_num<ir>';
+ my @sorted = sort {ascii_then_num} ('item', ...);
+
+Generate directly without Sort::Sub:
+
+ use Sort::Sub::ascii_then_num;
+ my $sorter = Sort::Sub::ascii_then_num::gen_sorter(
+     ci => 1,      # default 0, set 1 to sort case-insensitively
+     reverse => 1, # default 0, set 1 to sort in reverse order
+ );
+ my @sorted = sort $sorter ('item', ...);
+
+Use in shell/CLI with L<sortsub> (from L<App::sortsub>):
+
+ % some-cmd | sortsub ascii_then_num
+ % some-cmd | sortsub ascii_then_num --ignore-case -r
+
+=head1 DESCRIPTION
+
+This module can generate sort subroutine. It is meant to be used via L<Sort::Sub>, although you can also use it directly via C<gen_sorter()>.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Sort-Sub>.
@@ -79,6 +109,8 @@ feature.
 
 =head1 SEE ALSO
 
+L<Sort::Sub>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
