@@ -1,7 +1,7 @@
 package Sort::Sub::naturally;
 
-our $DATE = '2016-12-16'; # DATE
-our $VERSION = '0.07'; # VERSION
+our $DATE = '2016-12-17'; # DATE
+our $VERSION = '0.08'; # VERSION
 
 use 5.010;
 use strict;
@@ -56,10 +56,40 @@ Sort::Sub::naturally - Sort naturally
 
 =head1 VERSION
 
-This document describes version 0.07 of Sort::Sub::naturally (from Perl distribution Sort-Sub), released on 2016-12-16.
+This document describes version 0.08 of Sort::Sub::naturally (from Perl distribution Sort-Sub), released on 2016-12-17.
 
 =for Pod::Coverage ^(gen_sorter)$
 
+=head1 SYNOPSIS
+
+Generate sorter (accessed as variable) via L<Sort::Sub> import:
+
+ use Sort::Sub '$naturally'; # use '$naturally<i>' for case-insensitive sorting, '$naturally<r>' for reverse sorting
+ my @sorted = sort $naturally ('item', ...);
+
+Generate sorter (accessed as subroutine):
+
+ use Sort::Sub 'naturally<ir>';
+ my @sorted = sort {naturally} ('item', ...);
+
+Generate directly without Sort::Sub:
+
+ use Sort::Sub::naturally;
+ my $sorter = Sort::Sub::naturally::gen_sorter(
+     ci => 1,      # default 0, set 1 to sort case-insensitively
+     reverse => 1, # default 0, set 1 to sort in reverse order
+ );
+ my @sorted = sort $sorter ('item', ...);
+
+Use in shell/CLI with L<sortsub> (from L<App::sortsub>):
+
+ % some-cmd | sortsub naturally
+ % some-cmd | sortsub naturally --ignore-case -r
+
+=head1 DESCRIPTION
+
+This module can generate sort subroutine. It is meant to be used via L<Sort::Sub>, although you can also use it directly via C<gen_sorter()>.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Sort-Sub>.
@@ -78,6 +108,8 @@ feature.
 
 =head1 SEE ALSO
 
+L<Sort::Sub>
+
 L<Sort::Naturally>
 
 =head1 AUTHOR
